pub struct Config {
pub miner_address: Option<ZcashAddress>,
pub extra_coinbase_data: Option<String>,
pub internal_miner: bool,
}Expand description
Mining configuration section.
Fields
miner_address: Option<ZcashAddress>Address for receiving miner subsidy and tx fees.
Used in coinbase tx constructed in getblocktemplate RPC.
extra_coinbase_data: Option<String>Extra data to include in coinbase transaction inputs. Limited to around 95 bytes by the consensus rules.
If this string is hex-encoded, it will be hex-decoded into bytes. Otherwise, it will be UTF-8 encoded into bytes.
internal_miner: boolMine blocks using Zebra’s internal miner, without an external mining pool or equihash solver.
This experimental feature is only supported on regtest as it uses null solutions and skips checking for a valid Proof of Work.
The internal miner is off by default.
Implementations