pub fn default_miner_address(
kind: NetworkKind,
addr_type: &MinerAddressType,
) -> &'static strExpand description
Returns the hard-coded default miner address string for a given network and address type.
All addresses come from a single address:
- addresses for different networks are only different encodings of the same address;
- addresses of different types are components of the same unified address.